summaryrefslogtreecommitdiffstats
path: root/base/base_paths.h
diff options
context:
space:
mode:
Diffstat (limited to 'base/base_paths.h')
-rw-r--r--base/base_paths.h9
1 files changed, 4 insertions, 5 deletions
diff --git a/base/base_paths.h b/base/base_paths.h
index 72cff15..0f9be04 100644
--- a/base/base_paths.h
+++ b/base/base_paths.h
@@ -33,11 +33,10 @@ enum {
// for tests that need to locate various resources. It
// should not be used outside of test code.
#if defined(OS_POSIX)
- DIR_CACHE, // Directory where to put cache data. Note this is
- // *not* where the browser cache lives, but the
- // browser cache can be a subdirectory.
- // This is $XDG_CACHE_HOME on Linux and
- // ~/Library/Caches on Mac.
+ DIR_USER_CACHE, // Directory where user cache data resides. The Chromium
+ // browser cache can be a subdirectory of DIR_USER_CACHE.
+ // This is $XDG_CACHE_HOME on Linux and ~/Library/Caches
+ // on Mac.
#endif
PATH_END